'use strict';

const module$1 = require('module');
const path = require('path');
const process = require('process');
const constant = require('@babel/plugin-transform-react-constant-elements');
const env = require('@babel/preset-env');
const react = require('@babel/preset-react');
const commonjs = require('@mo36924/babel-plugin-commonjs');
const deadCodeElimination = require('@mo36924/babel-plugin-dead-code-elimination');
const iifeUnwrap = require('@mo36924/babel-plugin-iife-unwrap');
const inject = require('@mo36924/babel-plugin-inject');
const replace = require('@mo36924/babel-plugin-replace');
const resolve = require('@mo36924/babel-plugin-resolve');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

const process__default = /*#__PURE__*/_interopDefaultLegacy(process);
const constant__default = /*#__PURE__*/_interopDefaultLegacy(constant);
const env__default = /*#__PURE__*/_interopDefaultLegacy(env);
const react__default = /*#__PURE__*/_interopDefaultLegacy(react);
const commonjs__default = /*#__PURE__*/_interopDefaultLegacy(commonjs);
const deadCodeElimination__default = /*#__PURE__*/_interopDefaultLegacy(deadCodeElimination);
const iifeUnwrap__default = /*#__PURE__*/_interopDefaultLegacy(iifeUnwrap);
const inject__default = /*#__PURE__*/_interopDefaultLegacy(inject);
const replace__default = /*#__PURE__*/_interopDefaultLegacy(replace);
const resolve__default = /*#__PURE__*/_interopDefaultLegacy(resolve);

const _require = module$1.createRequire(path.join(process__default['default'].cwd(), "index.js"));
const { NODE_ENV, NODE_TARGET, NODE_NOMODULE } = process__default['default'].env;
const index = (_api, options) => {
    const { env: __ENV__ = NODE_ENV ?? "production", target: __TARGET__ = NODE_TARGET ?? "server", nomodule = NODE_NOMODULE !== "false" && !!NODE_NOMODULE, jsx = "preact", inject: _inject = {}, exports = {}, } = options;
    if (jsx === "react") {
        for (const mod of [
            "react",
            "react-dom",
            "react-dom/server",
            "react-dom/server.browser",
            "react/jsx-runtime",
            "react/jsx-dev-runtime",
        ]) {
            try {
                exports[mod] = Object.keys(_require(mod));
            }
            catch { }
        }
    }
    const __PROD__ = __ENV__ === "production" || undefined;
    const __DEV__ = __ENV__ === "development" || undefined;
    const __TEST__ = __ENV__ === "test" || undefined;
    const __SERVER__ = __TARGET__ === "server" || undefined;
    const __CLIENT__ = !__SERVER__ || undefined;
    const __NOMODULE__ = (__CLIENT__ && nomodule) || undefined;
    return {
        presets: [
            [
                env__default['default'],
                {
                    bugfixes: true,
                    modules: false,
                    loose: false,
                    ignoreBrowserslistConfig: true,
                    targets: __SERVER__
                        ? {
                            node: true,
                        }
                        : __NOMODULE__
                            ? {
                                android: "4.4",
                                chrome: "41",
                                edge: "16",
                                firefox: "60",
                                ie: "11",
                                ios: "10.3",
                                opera: "48",
                                safari: "10.1",
                                samsung: "8.2",
                            }
                            : {
                                esmodules: true,
                            },
                    useBuiltIns: false,
                    debug: __DEV__,
                },
            ],
            [
                react__default['default'],
                {
                    runtime: "automatic",
                    development: __DEV__,
                    importSource: jsx,
                },
            ],
        ],
        plugins: [
            [
                replace__default['default'],
                {
                    "typeof self": __SERVER__ ? '"undefined"' : '"object"',
                    "typeof global": __SERVER__ ? '"object"' : '"undefined"',
                    "typeof process": '"object"',
                    "process.env.NODE_ENV": `"${__ENV__}"`,
                    __ENV__: `"${__ENV__}"`,
                    __TARGET__: `"${__TARGET__}"`,
                    __PROD__,
                    __DEV__,
                    __TEST__,
                    __SERVER__,
                    __CLIENT__,
                    __NOMODULE__,
                    ...(__NOMODULE__ ? {} : { "typeof Event": __SERVER__ ? '"undefined"' : '"function"' }),
                    ...(__SERVER__ && { "typeof window": '"undefined"' }),
                },
            ],
            [deadCodeElimination__default['default']],
            [iifeUnwrap__default['default']],
            [
                resolve__default['default'],
                {
                    ignoreBuiltins: __SERVER__,
                    ignoreBareImport: __SERVER__,
                    aliasFields: __SERVER__ ? [] : ["browser"],
                    mainFields: __SERVER__ ? ["module", "main"] : ["browser", "module", "main"],
                    conditionNames: __SERVER__ ? ["import", "require"] : ["browser", "import", "require"],
                    extensions: __SERVER__
                        ? [
                            ".server.tsx",
                            ".server.ts",
                            ".server.jsx",
                            ".server.mjs",
                            ".server.js",
                            ".server.cjs",
                            ".server.json",
                            ".tsx",
                            ".ts",
                            ".jsx",
                            ".mjs",
                            ".js",
                            ".cjs",
                            ".json",
                            ".node",
                        ]
                        : [
                            ".client.tsx",
                            ".client.ts",
                            ".client.jsx",
                            ".client.mjs",
                            ".client.js",
                            ".client.cjs",
                            ".client.json",
                            ".tsx",
                            ".ts",
                            ".jsx",
                            ".mjs",
                            ".js",
                            ".cjs",
                            ".json",
                            ".node",
                        ],
                },
            ],
            [commonjs__default['default'], __SERVER__ ? false : exports],
            [inject__default['default'], _inject],
            [constant__default['default'], __PROD__ ? {} : false],
        ],
    };
};

module.exports = index;
//# sourceMappingURL=index.js.map
